import type EventModel from "./eventModel";
import TZDate from "../time/date";
interface EventUIProps {
    top: number;
    left: number;
    width: number;
    height: number;
    hasCollide: boolean;
    extraSpace: number;
    hidden: boolean;
    exceedLeft: boolean;
    exceedRight: boolean;
    croppedStart: boolean;
    croppedEnd: boolean;
    goingDurationHeight: number;
    modelDurationHeight: number;
    comingDurationHeight: number;
}
/**
 * Set of UI-related properties for calendar event.
 * @class
 * @param {EventModel} event EventModel instance.
 */
export default class EventUIModel implements EventUIProps {
    model: EventModel;
    top: number;
    left: number;
    width: number;
    height: number;
    /**
     * Represent event has collide with other events when rendering.
     * @type {boolean}
     */
    hasCollide: boolean;
    /**
     * Extra space at right side of this event.
     * @type {number}
     */
    extraSpace: number;
    /**
     * represent this event block is not visible after rendered.
     *
     * in month view, some ui models in date need to hide when already rendered before dates.
     *
     * set true then it just shows empty space.
     * @type {boolean}
     */
    hidden: boolean;
    /**
     * represent render start date used at rendering.
     *
     * if set null then use model's 'start' property.
     * @type {TZDate}
     */
    renderStarts?: TZDate;
    /**
     * represent render end date used at rendering.
     *
     * if set null then use model's 'end' property.
     * @type {TZDate}
     */
    renderEnds?: TZDate;
    /**
     * whether the actual start-date is before the render-start-date
     * @type {boolean}
     */
    exceedLeft: boolean;
    /**
     * whether the actual end-date is after the render-end-date
     * @type {boolean}
     */
    exceedRight: boolean;
    /**
     * whether the actual start-date is before the render-start-date for column
     * @type {boolean}
     */
    croppedStart: boolean;
    /**
     * whether the actual end-date is after the render-end-date for column
     * @type {boolean}
     */
    croppedEnd: boolean;
    /**
     * @type {number} percent
     */
    goingDurationHeight: number;
    /**
     * @type {number} percent
     */
    modelDurationHeight: number;
    /**
     * @type {number} percent
     */
    comingDurationHeight: number;
    constructor(event: EventModel);
    /**
     * EventUIModel factory method.
     */
    static create(event: EventModel): EventUIModel;
    getUIProps(): EventUIProps;
    setUIProps(props: Partial<EventUIProps>): void;
    /**
     * return renderStarts property to render properly when specific event that exceed rendering date range.
     *
     * if renderStarts is not set. return model's start property.
     */
    getStarts(): TZDate;
    /**
     * return renderStarts property to render properly when specific event that exceed rendering date range.
     *
     * if renderEnds is not set. return model's end property.
     */
    getEnds(): TZDate;
    /**
     * @returns {number} unique number for model.
     */
    cid(): number;
    /**
     * Shadowing valueOf method for event sorting.
     */
    valueOf(): EventModel;
    /**
     * Link duration method
     * @returns {number} EventModel#duration result.
     */
    duration(): number;
    collidesWith(uiModel: EventModel | EventUIModel, usingTravelTime?: boolean): boolean;
    clone(): EventUIModel;
}
export {};
